@@ -50,7 +50,7 @@ class SampleAccuracyTest(BaseTest):
         with open(
             f"{os.path.dirname(os.path.realpath(__file__))}/sample_report_template.html"
         ) as file_:
-            template = jinja2.Template(file_.read())
+            template = jinja2.Template(file_.read(), autoescape=True)
 
         uni_images = {
             title: transform_to_base64(path)
