@@ -1,4 +1,4 @@
-from syngen.ml.vae.wrappers.wrappers import (
+from syngen.ml.vae.wrappers.wrappers import (  # noqa: F401;
     BaseWrapper,
     VAEWrapper,
     VanillaVAEWrapper
